==> bit_ads_pakage-1.0.6.tar.gz: README.md <==
<!-- 
This README describes the package. If you publish this package to pub.dev,
this README's contents appear on the landing page for your package.

For information about how to write a good package README, see the guide for
[writing package pages](https://dart.dev/guides/libraries/writing-package-pages). 

For general information about developing packages, see the Dart guide for
[creating packages](https://dart.dev/guides/libraries/create-library-packages)
and the Flutter guide for
[developing packages and plugins](https://flutter.dev/developing-packages). 
-->


## UnityAds

TODO: Show Intra Ads

```dart
UnityAds.showVideoAd(
  placementId: 'PLACEMENT_ID',
  onStart: (placementId) => print('Video Ad $placementId started'),
  onClick: (placementId) => print('Video Ad $placementId click'),
  onSkipped: (placementId) => print('Video Ad $placementId skipped'),
  onComplete: (placementId) => print('Video Ad $placementId completed'),
  onFailed: (placementId, error, message) => print('Video Ad $placementId failed: $error $message'),
);
```

TODO: Show Banner Ads

```dart
Googleads.unityBannerShow;
```


## Getting started

TODO: List prerequisites and provide or point to information on how to
start using the package.

## Usage

TODO: Include short and useful examples for package users. Add longer examples
to `/example` folder. 

```dart
const like = 'sample';
```


01) 
for admob 
<meta-data
android:name="com.google.android.gms.ads.APPLICATION_ID"
android:value="ca-app-pub-3940256099942544~3347511713"/>

for adx
<meta-data
android:name="com.google.android.gms.ads.AD_MANAGER_APP"
android:value="true"/>


02)
-WidgetsFlutterBinding.ensureInitialized();
-Admob.initialize();


03) show ads
final isLoaded = await interstitialAd.isLoaded;
if (isLoaded ?? false) {
interstitialAd.show();
} else {
showSnackBar(
'Interstitial ad is still loading...');
}

    
----------------------------------
ad manager test id
Banner :- /6499/example/banner
Intra :- /6499/example/interstitial
Reward :- /6499/example/rewarded


admob test id
Banner :- ca-app-pub-3940256099942544/6300978111
Intra :-  ca-app-pub-3940256099942544/1033173712
Reward :- ca-app-pub-3940256099942544/5224354917
---------------------------------------
## Additional information

TODO: Tell users more about the package: where to find more information, how to 
contribute to the package, how to file issues, what response they can expect 
from the package authors, and more.

==> bit_ads_pakage-1.0.7.tar.gz: README.md <==
<!-- 
This README describes the package. If you publish this package to pub.dev,
this README's contents appear on the landing page for your package.

For information about how to write a good package README, see the guide for
[writing package pages](https://dart.dev/guides/libraries/writing-package-pages). 

For general information about developing packages, see the Dart guide for
[creating packages](https://dart.dev/guides/libraries/create-library-packages)
and the Flutter guide for
[developing packages and plugins](https://flutter.dev/developing-packages). 
-->

## Getting started

## UnityAds

TODO: Initialization in void main

```dart
Unityads.iniUnit();
```

TODO: Load Intra Ads

```dart
Unityads.unityIntraLoad();
```

TODO: Show Intra Ads

```dart
UnityAds.showVideoAd(
  placementId: 'PLACEMENT_ID',
  onStart: (placementId) => print('Video Ad $placementId started'),
  onClick: (placementId) => print('Video Ad $placementId click'),
  onSkipped: (placementId) => print('Video Ad $placementId skipped'),
  onComplete: (placementId) => print('Video Ad $placementId completed'),
  onFailed: (placementId, error, message) => print('Video Ad $placementId failed: $error $message'),
);
```

TODO: Show Banner Ads

```dart
Unityads.unityBannerShow;
```


## Admob Ads

TODO: Initialization in void main

```dart
Googleads.ini;
```

TODO: add app id in android mainfiest file

```dart
<manifest>
  <application>
    <meta-data
      android:name="com.google.android.gms.ads.APPLICATION_ID"
      android:value="ca-app-pub-3940256099942544~3347511713"/>
  </application>
</manifest>
```
